library flutter_dynamic_ui;

import 'package:flutter_dynamic_ui/default/default_registry.dart';
import 'package:flutter_dynamic_ui/http/http_parser.dart';
import 'package:flutter_dynamic_ui/manager/action_manager.dart';
import 'package:flutter_dynamic_ui/manager/block_manager.dart';
import 'package:flutter_dynamic_ui/manager/card_manager.dart';
import 'package:flutter_dynamic_ui/manager/style_manager.dart';
import 'package:flutter_dynamic_ui/storage/asset_parser.dart';

export 'actions/action_config.dart';
export 'actions/action_generator.dart';
export 'api/parser.dart';
export 'builder/block_builder.dart';
export 'builder/card_builder.dart';
export 'builder/page_builder.dart';
export 'component/base_block.dart';
export 'component/base_card.dart';
export 'component/component.dart';
export 'http/http_parser.dart';
export 'manager/block_manager.dart';
export 'manager/card_manager.dart';
export 'manager/registry.dart';
export 'model/data_model.dart';
export 'storage/asset_parser.dart';
export 'style/style_utils.dart';

class FlutterDynamicUi {
  static void registerDefaultComponent() {
    CardManager.getInstance().addRegistry(DefaultCardRegistry());
    BlockManager.getInstance().addRegistry(DefaultBlockRegistry());
    ActionManager.getInstance().addRegistry(DefaultActionRegistry());
  }

  static void initStylesFromAssets(String filename, Function block) {
    AssetParser()
        .parseStyleData(filename)
        .then((value) => StyleManager.getInstance().saveStylesData(value))
        .then((value) => block());
  }

  static void initStylesFromUrl(String url, Function block) {
    HttpParser()
        .parseStyleData(url)
        .then((value) => StyleManager.getInstance().saveStylesData(value))
        .then((value) => block());
  }
}
