import 'dart:collection';

import 'package:flutter/cupertino.dart';
import 'package:flutter_dynamic_ui/component/base_card.dart';
import 'package:flutter_dynamic_ui/manager/registry.dart';
import 'package:flutter_dynamic_ui/model/data_model.dart';

class CardManager {
  static CardManager _instance;

  CardManager._internal() {
    if (cardMap == null) {
      cardMap = HashMap<String, BaseCard>();
    }
  }

  factory CardManager.getInstance() => _getInstance();

  static _getInstance() {
    if (_instance == null) {
      _instance = CardManager._internal();
    }
    return _instance;
  }

  Map<String, BaseCard> cardMap;

  Widget getCardWidget(BuildContext context, CardData cardData) {
    final type = cardData.type;
    if (cardMap.containsKey(type)) {
      return cardMap[type].createWidget(context, cardData);
    } else {
      // fallback
      return Container(
        child: Center(
          child: Text("Card No Found"),
        ),
      );
    }
  }

  void addRegistry(CardRegistry registry) {
    Map<String, BaseCard> map = registry.getMap();
    cardMap.addAll(map);
  }
}
