import 'package:json_annotation/json_annotation.dart';

part 'data_model.g.dart';

@JsonSerializable()
class PageData {
  String id;

  @JsonKey(name: "cards")
  List<CardData> cardList;

  Map<String, dynamic> extras;

  PageData({this.id, this.cardList, this.extras});

  factory PageData.fromJson(Map<String, dynamic> json) =>
      _$PageDataFromJson(json);

  Map<String, dynamic> toJson() => _$PageDataToJson(this);

  @override
  String toString() {
    return 'Page{id: $id, cardList: $cardList, extras: $extras}';
  }
}

@JsonSerializable()
class CardData {
  String id;
  String type;
  @JsonKey(name: "blocks")
  List<BlockData> blockList;

  @JsonKey(name: "card_class")
  String cardClass;

  @JsonKey(name: "top_banner")
  BlockData topBanner;

  @JsonKey(name: "bottom_banner")
  BlockData bottomBanner;

  Map<String, dynamic> extras;

  CardData(
      {this.id,
      this.type,
      this.blockList,
      this.cardClass,
      this.topBanner,
      this.bottomBanner,
      this.extras});

  factory CardData.fromJson(Map<String, dynamic> json) =>
      _$CardDataFromJson(json);

  Map<String, dynamic> toJson() => _$CardDataToJson(this);

  @override
  String toString() {
    return 'Card{id: $id, type: $type, blockList: $blockList, extras: $extras}';
  }
}

@JsonSerializable()
class BlockData {
  String id;
  String type;
  Map<String, dynamic> extras;

  @JsonKey(name: "metas")
  List<Meta> metaList;

  @JsonKey(name: "btns")
  List<Btn> btnList;

  @JsonKey(name: "imgs")
  List<Img> imgList;

  @JsonKey(name: "block_class")
  String blockClass;

  @JsonKey(name: "actions")
  Map<String, ActionData> actionData;

  BlockData(
      {this.id,
      this.type,
      this.extras,
      this.metaList,
      this.btnList,
      this.imgList,
      this.blockClass,
      this.actionData});

  factory BlockData.fromJson(Map<String, dynamic> json) =>
      _$BlockDataFromJson(json);

  Map<String, dynamic> toJson() => _$BlockDataToJson(this);

  @override
  String toString() {
    return 'Block{id: $id, type: $type, extras: $extras}';
  }
}

@JsonSerializable()
class Meta {
  String text;

  @JsonKey(name: "meta_class")
  String metaClass;

  @JsonKey(name: "actions")
  Map<String, ActionData> actionData;

  Meta({this.text, this.metaClass, this.actionData});

  factory Meta.fromJson(Map<String, dynamic> json) => _$MetaFromJson(json);

  Map<String, dynamic> toJson() => _$MetaToJson(this);

  @override
  String toString() {
    return 'Meta{text: $text}';
  }
}

@JsonSerializable()
class Btn {
  String text;

  @JsonKey(name: "button_class")
  String btnClass;

  @JsonKey(name: "actions")
  Map<String, ActionData> actionData;

  Btn({this.text, this.btnClass, this.actionData});

  factory Btn.fromJson(Map<String, dynamic> json) => _$BtnFromJson(json);

  Map<String, dynamic> toJson() => _$BtnToJson(this);

  @override
  String toString() {
    return 'Btn{text: $text}';
  }
}

@JsonSerializable()
class Img {
  String url;

  @JsonKey(name: "image_class")
  String imgClass;

  @JsonKey(name: "actions")
  Map<String, ActionData> actionData;

  Img({this.url, this.imgClass, this.actionData});

  factory Img.fromJson(Map<String, dynamic> json) => _$ImgFromJson(json);

  Map<String, dynamic> toJson() => _$ImgToJson(this);

  @override
  String toString() {
    return 'Img{url: $url}';
  }
}

@JsonSerializable()
class Custom {
  Custom();

  factory Custom.fromJson(Map<String, dynamic> json) => _$CustomFromJson(json);

  Map<String, dynamic> toJson() => _$CustomToJson(this);
}

@JsonSerializable()
class ActionData {
  @JsonKey(name: "action_type")
  String actionType;

  Map<String, dynamic> data;

  ActionData({this.actionType, this.data});

  factory ActionData.fromJson(Map<String, dynamic> json) =>
      _$ActionDataFromJson(json);

  Map<String, dynamic> toJson() => _$ActionDataToJson(this);
}
