import 'package:json_annotation/json_annotation.dart';

part 'style_model.g.dart';

@JsonSerializable()
class StylesData {
  String id;
  String version;
  Map<String, LayoutStyle> layouts;

  @JsonKey(name: "csses")
  Map<String, CssStyle> cssStyles;

  StylesData({this.id, this.version, this.layouts, this.cssStyles});

  factory StylesData.fromJson(Map<String, dynamic> json) =>
      _$StylesDataFromJson(json);

  Map<String, dynamic> toJson() => _$StylesDataToJson(this);
}

@JsonSerializable()
class LayoutStyle {
  @JsonKey(name: "row_count")
  String rowCount;

  List<RowStyle> rows;

  LayoutStyle({this.rowCount, this.rows});

  factory LayoutStyle.fromJson(Map<String, dynamic> json) =>
      _$LayoutStyleFromJson(json);

  Map<String, dynamic> toJson() => _$LayoutStyleToJson(this);
}

@JsonSerializable()
class RowStyle {
  @JsonKey(name: "block_count")
  String blockCount;

  @JsonKey(name: "row_margin_style")
  String rowMarginStyle;
  String repeat;

  @JsonKey(name: "block_gap_style")
  String blockGapStyle;
  String ratio;

  RowStyle(
      {this.blockCount,
      this.rowMarginStyle,
      this.repeat,
      this.blockGapStyle,
      this.ratio});

  factory RowStyle.fromJson(Map<String, dynamic> json) =>
      _$RowStyleFromJson(json);

  Map<String, dynamic> toJson() => _$RowStyleToJson(this);
}

@JsonSerializable()
class CssStyle {
  ElementStyle value;

  CssStyle({this.value});

  factory CssStyle.fromJson(Map<String, dynamic> json) =>
      _$CssStyleFromJson(json);

  Map<String, dynamic> toJson() => _$CssStyleToJson(this);
}

@JsonSerializable()
class ElementStyle {
  String margin;
  String padding;
  String width;
  String height;

  @JsonKey(name: "font-size")
  String fontSize;
  @JsonKey(name: "font-color")
  String fontColor;
  @JsonKey(name: "font-weight")
  String fontWeight;

  String align;
  @JsonKey(name: "inner-align")
  String innerAlign;

  @JsonKey(name: "text-lines")
  String textLines;
  String color;

  @JsonKey(name: "background-color")
  String backgroundColor;

  @JsonKey(name: "border-radius")
  String borderRadius;

  @JsonKey(name: "border-color")
  String borderColor;

  @JsonKey(name: "border-width")
  String borderWidth;

  ElementStyle(
      {this.margin,
      this.padding,
      this.width,
      this.height,
      this.fontSize,
      this.fontColor,
      this.fontWeight,
      this.align,
      this.innerAlign,
      this.textLines,
      this.color,
      this.backgroundColor,
      this.borderRadius,
      this.borderColor,
      this.borderWidth});

  factory ElementStyle.fromJson(Map<String, dynamic> json) =>
      _$ElementStyleFromJson(json);

  Map<String, dynamic> toJson() => _$ElementStyleToJson(this);
}
