import 'dart:convert';

import 'package:flutter/foundation.dart';
import 'package:flutter/services.dart';
import 'package:flutter_dynamic_ui/api/parser.dart';
import 'package:flutter_dynamic_ui/model/data_model.dart';
import 'package:flutter_dynamic_ui/model/style_model.dart';

class AssetParser implements DataParser {
  @override
  Future<PageData> parsePageData(String filename) {
    return rootBundle.loadStructuredData<PageData>(
        filename, (value) => _parsePageData(value));
  }

  @override
  Future<StylesData> parseStyleData(String filename) {
    return rootBundle.loadStructuredData(
        filename, (value) => _parseStylesData(value));
  }

  Future<PageData> _parsePageData(String value) async {
    final Map<String, dynamic> jsonMap = jsonDecode(value);
    final page = PageData.fromJson(jsonMap);
    return SynchronousFuture(page);
  }

  Future<StylesData> _parseStylesData(String value) async {
    final Map<String, dynamic> jsonMap = jsonDecode(value);
    final styles = StylesData.fromJson(jsonMap);
    return SynchronousFuture(styles);
  }
}
