import 'dart:ui';

import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';

extension MarginExtension on String {
  EdgeInsets margin() {
    if (this == null) {
      return null;
    }
    return EdgeInsets.only(
        top: topMargin(),
        right: rightMargin(),
        bottom: bottomMargin(),
        left: leftMargin());
  }

  topMargin() {
    return this.split(" ")[0];
  }

  rightMargin() {
    return this.split(" ")[1];
  }

  bottomMargin() {
    return this.split(" ")[2];
  }

  leftMargin() {
    return this.split(" ")[3];
  }
}

extension PaddingExtension on String {
  EdgeInsets padding() {
    if (this == null) {
      return null;
    }
    return EdgeInsets.only(
        top: topPadding(),
        right: rightPadding(),
        bottom: bottomPadding(),
        left: leftPadding());
  }

  topPadding() {
    return this.split(" ")[0];
  }

  rightPadding() {
    return this.split(" ")[1];
  }

  bottomPadding() {
    return this.split(" ")[2];
  }

  leftPadding() {
    return this.split(" ")[3];
  }
}

extension ColorExtension on String {
  Color toColor() {
    var hexColor = this.replaceAll("#", "");
    if (hexColor.length == 6) {
      hexColor = "FF" + hexColor;
    }
    if (hexColor.length == 8) {
      return Color(int.parse("0x$hexColor"));
    }
    return Colors.transparent;
  }
}

extension MarginPaddingSizeExtension on Widget {
  Widget extend({
    String margin,
    String padding,
    String width,
    String height,
    String borderRadius,
    String borderColor,
    String borderWidth,
  }) {
    return Container(
      width: double.tryParse(width ?? "100.0") ?? null,
      height: double.tryParse(height ?? "100.0") ?? null,
      margin: margin.margin(),
      padding: padding.padding(),
      decoration: ShapeDecoration(
          shape: RoundedRectangleBorder(
        borderRadius:
            BorderRadius.circular(double.tryParse(borderRadius ?? "0.0")),
      )),
    );
  }
}
